@@ -7,15 +7,24 @@ sub init {
     my ($self, $conf) = @_;
     my $exe;
     $exe = `which cpan-upload-http` || `which cpan-upload`;
-    die "cpan-upload-http not found\n" unless $exe;
     chomp $exe;
+    die "cpan-upload-http not found\n" unless $exe;
     $self->{exe} = $exe;
 }
 
 sub run {
     my ($self, $state) = @_;
+    my $distfile =  $state->distfile;
+    die "No distfile was created!"             unless $distfile;
+    die "distfile $distfile no longer exists!" unless -e $distfile;
+
+    if ($state->dry_run) {
+        warn "*** DRY RUN, not uploading to CPAN!\n";
+        return;
+    }
+
     return unless bool_prompt("Upload to CPAN?", "y");
-    system($self->{exe}, $state->distfile) and die
+    system($self->{exe}, $distfile) and die
         "Upload failed.\n";
 }
 
